package ch.hevs.kart.comm;

import ch.hevs.kart.comm.protocol.Protocol;

/**
 * This interface will be used by the CommunicationSetup class in order to report
 * 	      communication setup status back to the caller.
 * 
 * @author Michael Clausen (clm@hevs.ch)
 *
 */
public interface CommunicationSetupListener {
	/**
	 * Called at the very end of the communication setup process in order to signal success.
	 * 
	 * @param protocol	Reference to the protocol object instantiated on top of the transport. This
	 * 					object is ready to use in order to talk to the kart.
	 */
	void communicationSetupSucceeded(Protocol protocol);
	
	/**
	 * Called if an communication setup process fails.
	 * 
	 * @param reason	The string describing the reason the communication setup process failed.
	 */
	void communicationSetupFailed(String reason);
}
