package ch.hevs.kart.comm.transport;

import java.nio.ByteBuffer;

/**
 * Common interface for all transport channels that can be used to communicate with the 
 * 		  Kart.
 * 
 * @author Michael Clausen (clm@hevs.ch)
 */
@SuppressWarnings("UnusedParameters")
public interface TransportListener {
	/**
	 * Data has been received from the peer device (the Kart).
	 * 
	 * @param transport	The transport object that actually has received the data.
	 * @param buffer	Data buffer.
	 */
	void dataIndication(Transport transport, ByteBuffer buffer);
	
	/**
	 * The state of the connection has changed.
	 * @param transport	The transport object that has changed its state.
	 * @param state		The actual state of the transfer object.
	 */
	void stateChangeIndication(Transport transport, TransportState state);
	
	/**
	 * Called whenever there was an error in the the link to the Kart.
	 * 
	 * @param transport	The transport object actually notifying. 
	 * @param error		A description of the error as a string.
	 */
	void errorIndication(Transport transport, String error);
}
